@@ -924,12 +924,12 @@ def circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
     _inc_Z = np.random.randint(20,30)
     llZ = np.random.randint(0,1)
     sm = len(_tmp_ver_pkd)
+    if llZ == 0:
+        _inc_Z = -_inc_Z
+        
     for i in range(sm):
         for idx_ver in _tmp_ver_pkd[i]:
-            if llZ == 0:
-                mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] + _inc_Z*(sm - i)/sm
-            else:
-                mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] - _inc_Z*(sm - i)/sm
+            mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] + _inc_Z*(sm - i)/sm
 
     # newpath = path + "_" + str(index) + ".obj"
     # mesh_pre.export(newpath)
@@ -1008,12 +1008,12 @@ def longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
     _inc_Z = np.random.randint(20,30)
     llZ = np.random.randint(0,1)
     sm = len(_tmp_ver_pkd)
+    if llZ == 0:
+        _inc_Z = -_inc_Z
+        
     for i in range(sm):
         for idx_ver in _tmp_ver_pkd[i]:
-            if llZ == 0:
-                mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] + _inc_Z*(sm - i)/sm
-            else:
-                mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] - _inc_Z*(sm - i)/sm
+            mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] + _inc_Z*(sm - i)/sm
 
     # newpath = path + "_" + str(index) + ".obj"
     # mesh_pre.export(newpath)
@@ -1029,7 +1029,7 @@ def longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max):
 
 
 
-def scarCreatingV2(mesh, path, numGenCirScar=10):
+def scarCreatingV2(mesh, path, numGenScar=10):
     """
         scarCreating version 2
     """
@@ -1038,12 +1038,12 @@ def scarCreatingV2(mesh, path, numGenCirScar=10):
     
     circleScarMeshList = [
         circleScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max)
-        for index in range(numGenCirScar/2)
+        for index in range(int(numGenScar/2))
         ]
 
     longScarMeshList = [
         longScar(mesh, index, path, list_face_of_vertice, limitY_min, limitY_max)
-        for index in range(numGenCirScar/2, numGenCirScar)
+        for index in range(int(numGenScar/2), numGenScar)
         ]
 
     return circleScarMeshList, longScarMeshList
\ No newline at end of file
